@@ -47,8 +47,7 @@ CREATE TABLE answer
 	last_edited_by_id INTEGER NULL,
 	html LONGTEXT NOT NULL,
 	vote_up_count INTEGER NOT NULL,
-	vote_down_count INTEGER NOT NULL,
-	accepted_at DATETIME NULL
+	vote_down_count INTEGER NOT NULL
 ) ENGINE=InnoDB AUTO_INCREMENT=37 DEFAULT CHARSET=utf8;
 
 /* Table Items: answer */
@@ -284,15 +283,13 @@ CREATE TABLE book_author_info
 	blog_url VARCHAR(255) NULL,
 	user_id INTEGER NOT NULL,
 	added_at DATETIME NOT NULL,
-	last_edited_at DATETIME NOT NULL,
-	book_id INTEGER NOT NULL
+	last_edited_at DATETIME NOT NULL
 ) TYPE=InnoDB;
 
 /* Table Items: book_author_info */
 
 /* Add Indexes for: book_author_info */
 CREATE INDEX fk_book_author_info_auth_user ON book_author_info (user_id);
-CREATE INDEX fk_book_author_info_book ON book_author_info (book_id);
 
 /******************** Add Table: book_author_rss ************************/
 
@@ -304,15 +301,13 @@ CREATE TABLE book_author_rss
 	url VARCHAR(255) NOT NULL,
 	rss_created_at DATETIME NOT NULL,
 	user_id INTEGER NOT NULL,
-	added_at DATETIME NOT NULL,
-	book_id INTEGER NOT NULL
+	added_at DATETIME NOT NULL
 ) TYPE=InnoDB;
 
 /* Table Items: book_author_rss */
 
 /* Add Indexes for: book_author_rss */
 CREATE INDEX fk_book_author_rss_auth_user ON book_author_rss (user_id);
-CREATE INDEX fk_book_author_rss_book ON book_author_rss (book_id);
 
 /******************** Add Table: book_question ************************/
 
@@ -767,18 +762,10 @@ ALTER TABLE book ADD CONSTRAINT fk_books_auth_user
 ALTER TABLE book_author_info ADD CONSTRAINT fk_book_author_info_auth_user
 	FOREIGN KEY (user_id) REFERENCES auth_user (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
 
-/************ Foreign Key: fk_book_author_info_book ***************/
-ALTER TABLE book_author_info ADD CONSTRAINT fk_book_author_info_book
-	FOREIGN KEY (book_id) REFERENCES book (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
-
 /************ Foreign Key: fk_book_author_rss_auth_user ***************/
 ALTER TABLE book_author_rss ADD CONSTRAINT fk_book_author_rss_auth_user
 	FOREIGN KEY (user_id) REFERENCES auth_user (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
 
-/************ Foreign Key: fk_book_author_rss_book ***************/
-ALTER TABLE book_author_rss ADD CONSTRAINT fk_book_author_rss_book
-	FOREIGN KEY (book_id) REFERENCES book (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
-
 /************ Foreign Key: fk_book_question_book ***************/
 ALTER TABLE book_question ADD CONSTRAINT fk_book_question_book
 	FOREIGN KEY (book_id) REFERENCES book (id) ON UPDATE NO ACTION ON DELETE NO ACTION;
